@@ -11,7 +11,7 @@ from syncthing_gtk import *
 from syncthing_gtk.tools import *
 from syncthing_gtk.tools import _ # gettext function
 from datetime import datetime
-import os, webbrowser, sys, logging, shutil, re
+import os, webbrowser, sys, time, logging, shutil, re
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
@@ -49,6 +49,9 @@ RESPONSE_UR_FORBID		= 275
 REFRESH_INTERVAL_DEFAULT	= 1
 REFRESH_INTERVAL_TRAY		= 5
 
+# If daemon dies twice in this interval, broken settings are assumed
+RESTART_TOO_FREQUENT_INTERVAL = 5
+
 UPDATE_CHECK_INTERVAL = 12 * 60 * 60
 
 # Speed values in outcoming/incoming speed limit menus
@@ -77,6 +80,7 @@ class App(Gtk.Application, TimerManager):
 		self.process = None
 		self.hide_window = self.config["minimize_on_start"]
 		self.exit_after_wizard = False
+		self.last_restart_time = 0.0
 		# Can be changed by --force-update=vX.Y.Z argument
 		self.force_update_version = None
 		# Determine if header bar should be shown
@@ -315,7 +319,7 @@ class App(Gtk.Application, TimerManager):
 			if IS_XP:
 				# Wizard can't run on old Windows versions. Instead of
 				# it, 'Give me daemon executable' dialog is shown
-				self.cb_daemon_startup_failed(None, "File not found")
+				self.cb_daemon_startup_failed(None, "Syncthing is not configured or configuration file cannot be found.")
 				return False
 			self.hide()
 			self.show_wizard()
@@ -403,7 +407,11 @@ class App(Gtk.Application, TimerManager):
 		Sets self.process, adds related handlers and starts daemon.
 		Just so I don't have to write same code all over the place.
 		"""
-		self.process = DaemonProcess([self.config["syncthing_binary"], "-no-browser"], self.config["daemon_priority"], self.config["max_cpus"])
+		cmdline = [self.config["syncthing_binary"], "-no-browser"]
+		vars, preargs, args = parse_config_arguments(self.config["syncthing_arguments"])
+		cmdline = preargs + cmdline + args
+		
+		self.process = DaemonProcess(cmdline, self.config["daemon_priority"], self.config["max_cpus"], env=vars)
 		self.process.connect('failed', self.cb_daemon_startup_failed)
 		self.process.connect('exit', self.cb_daemon_exit)
 		self.process.start()
@@ -1939,10 +1947,14 @@ class App(Gtk.Application, TimerManager):
 			self.quit()
 	
 	def cb_daemon_exit(self, proc, error_code):
-		print "cb_daemon_exit", proc, self.process
 		if proc == self.process:
 			# Whatever happens, if daemon dies while it shouldn't,
-			# restart it
+			# restart it...
+			if time.time() - self.last_restart_time < RESTART_TOO_FREQUENT_INTERVAL:
+				# ... unless it keeps restarting
+				self.cb_daemon_startup_failed(proc, "Daemon exits too fast")
+				return
+			self.last_restart_time = time.time()
 			if not StDownloader is None and self.config["st_autoupdate"] and os.path.exists(self.config["syncthing_binary"] + ".new"):
 				# New daemon version is downloaded and ready to use.
 				# Switch to this version before restarting
