@@ -20,7 +20,7 @@ VALUES = [ "vautostart_daemon", "vautokill_daemon", "vminimize_on_start",
 		"vforce_dark_theme", "vdaemon_priority", "vfolder_as_path",
 		"vnotification_for_update", "vnotification_for_folder",
 		"vnotification_for_error", "vst_autoupdate", "vsyncthing_binary",
-		"vmax_cpus",
+		"vsyncthing_arguments", "vmax_cpus",
 	]
 
 # Values for filemanager integration. Key is ID of checkbox widget
